#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ULPDIST_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_ULPDIST_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/scalar/ulpdist.hpp>

#endif
